@@ -92,15 +92,13 @@
 	 #f)
 	((and (= slot-id 1) (> (length card-list) 1))
 	 #f)
+        ((and (> slot-id 1)
+              (< slot-id 6)
+              (= BASE-VAL (get-value (car card-list))))
+         #f)
 	(else
-	 (if card-list
-	     (if (is-visible? (car (reverse card-list)))
-		 (if (and (= slot-id 2)
-			  (= (length (get-cards 2)) 1))
-		     #f
-		     #t)
-		 #f)
-	     #f))))
+	 (and card-list
+	      (is-visible? (car (reverse card-list)))))))
 
 (define (complete-transaction start-slot card-list end-slot)
   (if (and (> start-slot 1)
@@ -164,9 +162,15 @@
 		    (and (= (get-value (get-top-card end-slot)) king)
 			   (= (get-value (car card-list)) ace)))) )))
 
+(define (dealable?)
+  (flippable? 0 1 -1))
+
+(define (do-deal-next-cards)
+  (flip-stock 0 1 -1 3))
+
 (define (button-clicked slot-id)
   (and (= slot-id 0)
-       (flip-stock 0 1 -1 3)))
+       (do-deal-next-cards)))
 
 (define (place-ace card slot)
   (remove-card slot)
@@ -193,12 +197,12 @@
 	  (place-found slot top-card (+ search 1)))))
 
 (define (button-double-clicked slot)
-  (if (and (or (> slot 5) (eq? slot 1))
-	   (not (empty-slot? slot)))
-      (let ((top-card (get-top-card slot)))
-	(if (eq? (get-value top-card) BASE-VAL)
-	    (place-ace top-card slot)
-	    (place-found slot top-card 2)))))
+  (and (or (> slot 5) (eq? slot 1))
+       (not (empty-slot? slot))
+       (let ((top-card (get-top-card slot)))
+         (if (eq? (get-value top-card) BASE-VAL)
+             (place-ace top-card slot)
+             (place-found slot top-card 2)))))
 
 (define (game-over)
   (and (or (get-valid-move '(6 7 8 9 10 1))
@@ -307,6 +311,6 @@
 
 (define (timeout) #f)
 
-(set-features droppable-feature)
+(set-features droppable-feature dealable-feature)
 
-(set-lambda new-game button-pressed button-released button-clicked button-double-clicked game-over game-won get-hint get-options apply-options timeout droppable?)
+(set-lambda new-game button-pressed button-released button-clicked button-double-clicked game-over game-won get-hint get-options apply-options timeout droppable? dealable?)
