@@ -1010,8 +1010,6 @@ toolbar_toggled_cb (GtkToggleAction *action,
   games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_TOOLBAR), state);
 }
 
-#ifndef HAVE_HILDON
-
 static void
 statusbar_toggled_cb (GtkToggleAction *action,
                       AisleriotWindow *window)
@@ -1028,8 +1026,6 @@ statusbar_toggled_cb (GtkToggleAction *action,
   games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_STATUSBAR), state);
 }
 
-#endif /* !HAVE_HILDON */
-
 static void
 set_fullscreen_actions (AisleriotWindow *window,
                         gboolean is_fullscreen)
@@ -1475,9 +1471,7 @@ aisleriot_window_take_card_theme (AisleriotWindow *window,
                                   GamesCardTheme *theme /* adopting */)
 {
   AisleriotWindowPrivate *priv = window->priv;
-#if GTK_CHECK_VERSION (2, 10, 0)
   GtkWidget *widget = GTK_WIDGET (window);
-#endif
 
   if (theme == priv->theme)
     return;
@@ -1487,14 +1481,12 @@ aisleriot_window_take_card_theme (AisleriotWindow *window,
   }
   priv->theme = theme;
 
-#if GTK_CHECK_VERSION (2, 10, 0)
   if (gtk_widget_has_screen (widget)) {
     const cairo_font_options_t *font_options;
 
     font_options = gdk_screen_get_font_options (gtk_widget_get_screen (widget));
     games_card_theme_set_font_options (theme, font_options);
   }
-#endif /* GTK+ 2.10.0 */
 
   aisleriot_board_set_card_theme (priv->board, theme);
 }    
@@ -1997,7 +1989,7 @@ game_exception_cb (AisleriotGame *game,
   gtk_widget_show (dialog);
 }
 
-#ifdef HAVE_CLUTTER
+#if defined(HAVE_CLUTTER) || defined(HAVE_CANBERRA_GTK)
 
 static void
 settings_changed_cb (GtkSettings *settings,
@@ -2007,11 +1999,30 @@ settings_changed_cb (GtkSettings *settings,
   AisleriotWindowPrivate *priv = window->priv;
   GtkAction *action;
   gboolean enabled;
+  const char *name;
 
-  g_object_get (settings, "gtk-enable-animations", &enabled, NULL);
+  if (pspec)
+    name = pspec->name;
+  else
+    name = NULL;
 
-  action = gtk_action_group_get_action (priv->action_group, "Animations");
-  gtk_action_set_visible (action, enabled);
+#ifdef HAVE_CLUTTER
+  if (name == NULL || strcmp (name, "gtk-enable-animations") == 0) {
+    g_object_get (settings, "gtk-enable-animations", &enabled, NULL);
+
+    action = gtk_action_group_get_action (priv->action_group, "Animations");
+    gtk_action_set_visible (action, enabled);
+  }
+#endif /* HAVE_CLUTTER */
+
+#ifdef HAVE_CANBERRA_GTK
+  if (name == NULL || strcmp (name, "gtk-enable-event-sounds") == 0) {
+    g_object_get (settings, "gtk-enable-event-sounds", &enabled, NULL);
+
+    action = gtk_action_group_get_action (priv->action_group, "Sound");
+    gtk_action_set_visible (action, enabled);
+  }
+#endif /* HAVE_CANBERRA_GTK */
 }
 
 static void
@@ -2037,11 +2048,17 @@ screen_changed_cb (GtkWidget *widget,
 
   settings = gtk_widget_get_settings (widget);
   settings_changed_cb (settings, NULL, window);
+#ifdef HAVE_CLUTTER
   g_signal_connect (settings, "notify::gtk-enable-animations",
                     G_CALLBACK (settings_changed_cb), window);
+#endif
+#ifdef HAVE_CANBERRA_GTK
+  g_signal_connect (settings, "notify::gtk-enable-event-sounds",
+                    G_CALLBACK (settings_changed_cb), window);
+#endif
 }
-  
-#endif /* HAVE_CLUTTER */
+
+#endif /* HAVE_CLUTTER || HAVE_CANBERRA_GTK */
 
 /* Class implementation */
 
@@ -2244,13 +2261,11 @@ aisleriot_window_init (AisleriotWindow *window)
       G_CALLBACK (toolbar_toggled_cb),
       FALSE
     },
-#ifndef HAVE_HILDON
     { "Statusbar", NULL, N_("_Statusbar"), NULL,
       ACTION_TOOLTIP (N_("Show or hide statusbar")),
       G_CALLBACK (statusbar_toggled_cb),
       FALSE
     },
-#endif /* !HAVE_HILDON */
     { "ClickToMove", NULL, N_("_Click to Move"), NULL,
       ACTION_TOOLTIP (N_("Pick up and drop cards by clicking")),
       G_CALLBACK (clickmove_toggle_cb),
@@ -2619,6 +2634,10 @@ aisleriot_window_init (AisleriotWindow *window)
   priv->toolbar_visible = games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_TOOLBAR), NULL) != FALSE;
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
                                 priv->toolbar_visible);
+  action = gtk_action_group_get_action (priv->action_group, "Statusbar");
+  priv->statusbar_visible = games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_STATUSBAR), NULL) != FALSE;
+  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
+                                priv->statusbar_visible);
   action = gtk_action_group_get_action (priv->action_group, "ClickToMove");
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
                                 games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_CLICK_TO_MOVE), NULL));
@@ -2629,13 +2648,6 @@ aisleriot_window_init (AisleriotWindow *window)
   action = gtk_action_group_get_action (priv->action_group, "RecentMenu");
   g_object_set (action, "hide-if-empty", FALSE, NULL);
 
-#ifndef HAVE_HILDON
-  action = gtk_action_group_get_action (priv->action_group, "Statusbar");
-  priv->statusbar_visible = games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_STATUSBAR), NULL) != FALSE;
-  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
-                                priv->statusbar_visible);
-#endif /* !HAVE_HILDON */
-
 #ifdef ENABLE_CARD_THEMES_INSTALLER
   action = gtk_action_group_get_action (priv->action_group, "InstallThemes");
   gtk_action_set_sensitive (action, games_card_themes_can_install_themes (priv->theme_manager));
@@ -2648,10 +2660,15 @@ aisleriot_window_init (AisleriotWindow *window)
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
                                 games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_ANIMATIONS), NULL));
 
-  /* Set the action visibility and listen for animation mode changes */
-  screen_changed_cb (GTK_WIDGET (window), NULL, window);
 #endif /* HAVE_CLUTTER */
 
+#if defined(HAVE_CLUTTER) || defined(HAVE_CANBERRA_GTK)
+  /* Set the action visibility and listen for animation and sound mode changes */
+  screen_changed_cb (GTK_WIDGET (window), NULL, window);
+  g_signal_connect (window, "screen-changed",
+                    G_CALLBACK (screen_changed_cb), window);
+#endif /* HAVE_CLUTTER || HAVE_CANBERRA_GTK */
+
   /* Now set up the widgets */
   main_vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (window), main_vbox);
