@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 __author__ = 'Robert Ancell <bob27@users.sourceforge.net>'
 __license__ = 'GNU General Public License Version 2'
 __copyright__ = 'Copyright 2005-2006  Robert Ancell'
@@ -38,7 +39,7 @@ class MovePlayer(game.ChessPlayer):
 
     def onPlayerMoved(self, p, move):
         self.view._redrawHighlight()
-            
+        
     def onPlayerStartTurn(self, player):
         self.view._redrawHighlight()
 
@@ -269,19 +270,23 @@ class Splashscreen(ui.ViewFeedback):
             rotation = 180.0
         else:
             rotation = 0.0
-        self.cairoScene.controller.setBoardRotation(rotation, animate)
-        self.scene.controller.setBoardRotation(rotation, animate)
+        self.cairoScene.controller.setBoardRotation(rotation, boardView == 'facetoface', animate)
+        self.scene.controller.setBoardRotation(rotation, boardView == 'facetoface', animate)
 
     def onRedraw(self):
         """Called by scene.SceneFeedback"""
         if self.controller is not None:
             self.controller.render()
-        
+            
     def showBoardNumbering(self, showNumbering):
         """Called by ui.ViewFeedback"""
         self.scene.showBoardNumbering(showNumbering)
         self.cairoScene.showBoardNumbering(showNumbering)
 
+    def showMoveHints(self, showHints):
+        """Called by ui.ViewFeedback"""
+        pass
+
     def renderGL(self):
         """Called by ui.ViewFeedback"""
         self.scene.render()
@@ -299,8 +304,18 @@ class Splashscreen(ui.ViewFeedback):
         self.scene.reshape(width, height)
         self.cairoScene.reshape(width, height)
 
+    def select(self, x, y):
+        pass
+    
+    def deselect(self, x, y):
+        pass    
+
     def selectSquare(self, coord):
         pass
+    
+    def undo(self):
+        """Called by ui.ViewFeedback"""
+        pass
 
     def resign(self):
         """Called by ui.ViewFeedback"""
@@ -334,6 +349,7 @@ class View(ui.ViewFeedback):
         self.selectedCoord = None
         self.showHints = False
         self.showNumbering = False
+        self.doSmooth = False
         self.highlightParams = (None, None, None, None)
         self.changedHighlight = True
         
@@ -415,7 +431,7 @@ class View(ui.ViewFeedback):
         
         # Decide if we should face this angle
         boardView = config.get('board_view')
-        if boardView == 'white':
+        if boardView == 'white' or boardView == 'facetoface':
             rotation = 0.0
         elif boardView == 'black':
             rotation = 180.0
@@ -423,7 +439,7 @@ class View(ui.ViewFeedback):
             if not isinstance(p, player.HumanPlayer):
                 return
 
-        self.scene.controller.setBoardRotation(rotation, animate)
+        self.scene.controller.setBoardRotation(rotation, boardView == 'facetoface', animate)
 
     def _pieceMoved(self, piece):
         """
@@ -444,6 +460,11 @@ class View(ui.ViewFeedback):
         """Called by ui.ViewFeedback"""
         self.showNumbering = showNumbering
         self.scene.controller.showBoardNumbering(showNumbering)
+        
+    def showSmooth(self, doSmooth):
+        """Called by ui.ViewFeedback"""
+        self.doSmooth = doSmooth
+        self.scene.controller.showSmooth(doSmooth)
 
     def updateScene(self, sceneClass):
         """
@@ -459,6 +480,7 @@ class View(ui.ViewFeedback):
         self.reshape(self.width, self.height)
         self.setMoveNumber(self.moveNumber)
         self.showBoardNumbering(self.showNumbering)
+        self.showSmooth(self.doSmooth)
         self.updateRotation(animate = False)
 
     def renderGL(self):
@@ -520,41 +542,41 @@ class View(ui.ViewFeedback):
 
     def save(self, fileName = None):
         """Called by ui.ViewFeedback"""
-        if fileName is None:
-            fileName = self.game.fileName
-            assert(fileName is not None)
+        # If filename supplied take out of the history
+        if fileName is not None:
+            if self.game.inHistory:
+                self.game.inHistory = False
+                if self.game.fileName is not None:
+                    self.game.application.history.rename(self.game.fileName, fileName)
+            self.game.fileName = fileName
+        return self.game.save()
 
-        try:
-            f = file(fileName, 'w')
-        except IOError, e:
-            return e.args[1]
-        
-        self.game.application.logger.addLine('Saving game %s to %s' % (repr(self.game.name), fileName))
-
-        pgnGame = chess.pgn.PGNGame()
-        self.game.toPGN(pgnGame)
-            
-        lines = pgnGame.getLines()
-        for line in lines:
-            f.write(line + '\n')
-        f.write('\n')
-        f.close()
-        
-        self.game.fileName = fileName
-        
     def getFileName(self):
         """Called by ui.ViewFeedback"""
+        # If in the history then prompt for a new name
+        if self.game.inHistory:
+            return None
         return self.game.fileName
+    
+    def undo(self):
+        """Called by ui.ViewFeedback"""
+        p = self.game.getHumanPlayer()
+        if p is not None:
+            p.undo()
         
     def resign(self):
         """Called by ui.ViewFeedback"""
         p = self.game.getHumanPlayer()
-        if p is not None:
+        if p is None:
+            # If no human players then abandon game
+            self.game.abandon()
+        else:
             p.resign()
             
     def claimDraw(self):
         """Called by ui.ViewFeedback"""
         # TODO: Have the UI ask if the player wants to make a move first or claim now (or abort)
         p = self.game.getHumanPlayer()
-        if p is not None:
-            p.claimDraw()
+        if p is None:
+            return False
+        return p.claimDraw()
