@@ -95,6 +95,7 @@ class ChessGame(game.ChessGame):
 
         self.view.showMoveHints(config.get('show_move_hints') is True)
         self.view.showBoardNumbering(config.get('show_numbering') is True)
+        self.view.showSmooth(config.get('show_3d_smooth') is True)        
         
         # Watch for piece moves with a player
         self.__movePlayer = player.MovePlayer(self)
@@ -224,9 +225,9 @@ class ChessGame(game.ChessGame):
         else:
             pgnGame.setTag(chess.pgn.TAG_RESULT, value)
 
-        rules = {game.RULE_RESIGN:  chess.pgn.TERMINATE_ABANDONED,
-                 game.RULE_TIMEOUT: chess.pgn.TERMINATE_TIME_FORFEIT,
-                 game.RULE_DEATH:   chess.pgn.TERMINATE_DEATH}
+        rules = {game.RULE_ABANDONMENT: chess.pgn.TERMINATE_ABANDONED,
+                 game.RULE_TIMEOUT:     chess.pgn.TERMINATE_TIME_FORFEIT,
+                 game.RULE_DEATH:       chess.pgn.TERMINATE_DEATH}
         try:
             value = rules[self.rule]
         except KeyError:
@@ -338,7 +339,7 @@ class UI(ui.UIFeedback):
         self.ggzConfig = network.GGZConfig()
         dialog = network.GGZNetworkDialog(self)
         self.networkDialog = dialog.controller = self.controller.addNetworkDialog(dialog)
-        for server in self.ggzConfig.servers:
+        for server in self.ggzConfig.getServers():
             dialog.controller.addProfile(server, server.name)
 
     def onAnimate(self, timeStep):
@@ -408,7 +409,7 @@ class UI(ui.UIFeedback):
     def onNewNetworkGame(self):
         """Called by ui.UIFeedback"""
         self.networkDialog.setVisible(True)
-
+        
     def onQuit(self):
         """Called by ui.UIFeedback"""
         self.application.quit()
@@ -647,10 +648,6 @@ class Application:
 
         return newGame
 
-    def addMove(self, view, move):
-        # TEMP
-        self.ui.controller.addMove(view, move)
-
     def start(self):
         """Run glChess.
         
