@@ -20,7 +20,6 @@
  */
 
 #include <config.h>
-#include <gnome.h>
 
 #include <sys/types.h>
 #include <string.h>
@@ -28,6 +27,10 @@
 #include <time.h>
 #include <dirent.h>
 
+#include <gtk/gtk.h>
+
+#include <libgames-support/games-runtime.h>
+
 #include "gameconfig.h"
 #include "gbdefs.h"
 
@@ -214,11 +217,9 @@ load_game_configs (void)
   G_CONST_RETURN gchar *dent;
   GDir *dir;
   gchar *buffer;
+  const char *dname;
 
-  gchar *dname = gnome_program_locate_file (NULL,
-					    GNOME_FILE_DOMAIN_APP_DATADIR,
-					    (GAME_NAME),
-					    FALSE, NULL);
+  dname = games_runtime_get_directory (GAMES_RUNTIME_GAME_GAMES_DIRECTORY);
 
   if (game_configs != NULL) {
     free_game_configs ();
