@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-import gtk, gobject
+import gtk
 
 # Convenience library for a new kind of UI -- for e.g. this game, we
 # don't really want to have dialogs. Nonetheless, it's convenient to
-# design dialogs in glade and run them in the standard manner... So we
+# design dialogs in gtkbuilder and run them in the standard manner... So we
 # create a new "dialog" interface via a hidden notebook.
 
 class SwappableArea (gtk.Notebook):
@@ -13,7 +13,7 @@ class SwappableArea (gtk.Notebook):
     response = None
     running = False
 
-    
+
     def __init__ (self,main_area):
         gtk.Notebook.__init__(self)
         self.set_show_tabs(False)
@@ -24,7 +24,7 @@ class SwappableArea (gtk.Notebook):
         child = d.child
         d.remove(child)
         return self.swallow_widget(child)
-        
+
     def swallow_widget (self, w):
         w.unparent()
         return self.append_page(w)
@@ -56,7 +56,7 @@ class SwappableArea (gtk.Notebook):
         self.response = None
         return tmp_response
 
-        
+
 
 if __name__ == '__main__':
 
