@@ -1,15 +1,11 @@
 # -*- coding: utf-8 -*-
-import sys
 import os, shutil
 import os.path
 import sudoku
 import random
-import pickle
 import time
 import pausable
 import threading
-import saver
-from gettext import gettext as _
 from defaults import *
 
 class SudokuGenerator:
@@ -51,7 +47,7 @@ class SudokuGenerator:
         x,y = upper - y,upper-x
         # reflect twice...
         return y, x
-            
+
     def make_symmetric_puzzle (self):
         nclues = self.clues/2
         buckshot = set(random.sample(self.all_coords,nclues))
@@ -86,7 +82,7 @@ class SudokuGenerator:
             new_puzzle.add(x,y,self.start_grid._get_(x,y))
         self.puzzles.append(new_puzzle)
         return new_puzzle
-    
+
     def make_puzzle_by_boxes (self,
                               skew_by=0.0,
                               max_squares=None,):
@@ -133,7 +129,7 @@ class SudokuGenerator:
             clued += clues
             if skew_by:
                 # Reduce our number of squares proportionally to
-                # skewiness. 
+                # skewiness.
                 max_squares = round(max_squares * skew_by)
         # shuffle ourselves...
         random.shuffle(nclues)
@@ -171,7 +167,7 @@ class SudokuGenerator:
             return solver.difficulty()
         else:
             return None
-        
+
     def generate_puzzle_for_difficulty (self,
                                         lower_target=0.3,
                                         upper_target=0.5,
@@ -303,7 +299,6 @@ class SudokuMaker:
                   puzzle_maker_args={'symmetrical':True},
                   batch_size = 5,
                   pickle_to = os.path.join(DATA_DIR,'puzzles')):
-        self.new_puzzles={}
         self.pickle_to = pickle_to
         self.paused = False
         self.terminated = False
@@ -313,6 +308,7 @@ class SudokuMaker:
         self.load()
         self.all_puzzles = {}
         self.played = self.get_pregenerated('finished')
+        self.n_available_sudokus = {'easy':None,'medium':None,'hard':None,'very hard':None}
 
     def load (self):
         try:
@@ -329,7 +325,7 @@ class SudokuMaker:
                 except:
                     print 'Problem copying base puzzles'
                     print 'Attempted to copy from %s to %s' % (source, target)
-                
+
     def get_pregenerated (self, difficulty):
         fname = os.path.join(self.pickle_to, difficulty.replace(' ','_'))
         try:
@@ -340,7 +336,7 @@ class SudokuMaker:
             return []
         else:
             return [line.strip() for line in lines]
-        
+
     def get_new_puzzle (self, difficulty, new=True):
         """Return puzzle with difficulty near difficulty.
 
@@ -380,12 +376,15 @@ class SudokuMaker:
         if not difficulty_category:
             return sum([self.n_puzzles(c,new=new) for c in sudoku.DifficultyRating.categories])
         else:
+            if self.n_available_sudokus[difficulty_category]:
+                return self.n_available_sudokus[difficulty_category]
             lines = self.get_pregenerated(difficulty_category)
             count = 0
             for line in lines:
                 if (not new) or line.split('\t')[0] not in self.played:
                     count+=1
-            return count
+            self.n_available_sudokus[difficulty_category] = count
+            return self.n_available_sudokus[difficulty_category]
 
     def list_puzzles (self, difficulty_category=None, new=True):
         """Return a list of all puzzles we have generated.
@@ -446,7 +445,7 @@ class SudokuMaker:
         if i < n:
             print 'WARNING: Not able to provide %s puzzles in levels %s'%(n,levels)
             print 'WARNING: Generate more puzzles if you really need this many puzzles!'
-        return puzzles    
+        return puzzles
 
     def get_puzzles (self, n, levels, new=True, randomize=True,
                      exclude=[]):
@@ -459,7 +458,7 @@ class SudokuMaker:
         if not n: return []
         assert(levels)
         puzzles = []
-        
+
         # Open files to read puzzles...
         files = {}
         for l in levels:
@@ -475,7 +474,7 @@ class SudokuMaker:
             if lev in finished:
                 il += 1
                 continue
-            
+
             if len(files[lev]) == 0:
                 finished.append(lev)
             else:
@@ -497,7 +496,7 @@ class SudokuMaker:
             print 'WARNING: Not able to provide %s puzzles in levels %s'%(n,levels)
             print 'WARNING: Generate more puzzles if you really need this many puzzles!'
 
-        return puzzles    
+        return puzzles
 
     # End convenience methods for accessing puzzles we've created
 
@@ -505,8 +504,8 @@ class SudokuMaker:
 
     def make_batch (self, diff_min=None, diff_max=None):
         self.new_generator = InterruptibleSudokuGenerator(**self.generator_args)
-        key = self.new_generator.start_grid.to_string()        
-        #while 
+        key = self.new_generator.start_grid.to_string()
+        #while
         #    self.new_generator = InterruptibleSudokuGenerator(**self.generator_args)
         #    key = self.new_generator.start_grid.to_string()
         #print 'We have our solution grid'
@@ -525,11 +524,8 @@ class SudokuMaker:
                 # self.solutions_by_puzzle[puzstring]=key
                 # self.all_puzzles[puzstring] = diff
                 # self.names[puzstring] = self.get_puzzle_name(_('Puzzle'))
-                self.new_puzzles[diff.value_category()] = self.new_puzzles.get(diff.value_category(),0) + 1
                 outpath = os.path.join(self.pickle_to,
                                        diff.value_category().replace(' ','_'))
-                print 'Writing to ',os.path.join(self.pickle_to,
-                                       diff.value_category().replace(' ','_'))
                 # Read through the existing file and make sure we're
                 # not a duplicate puzzle
                 existing = self.get_pregenerated(diff.value_category())
@@ -538,11 +534,10 @@ class SudokuMaker:
                         outfi = file(outpath,'a')
                         outfi.write(puzstring+'\t'+str(diff.value)+'\n')
                         outfi.close()
+                        self.n_available_sudokus[diff.value_category()]+=1
                     except IOError, e:
                         print 'Error appending pregenerated puzzle: %s' % e.strerror
 
-                print 'done writing...'
-
     def pause (self, *args):
         if hasattr(self,'new_generator'): self.new_generator.pause()
         self.paused = True
@@ -565,7 +560,6 @@ class SudokuMaker:
         self.terminated = False
         if hasattr(self,'new_generator'): self.new_generator.termintaed = False
         self.paused = False
-        #self.new_puzzles = {}
         generated = 0
         while not limit or generated < limit:
             if self.terminated:
@@ -583,7 +577,7 @@ class SudokuMaker:
     def get_difficulty (self, puz):
         return sudoku.SudokuRater(puz).difficulty()
 
-        
+
 if __name__ == '__main__':
     import time
     #puzzles=sg.generate_puzzles(30)
@@ -597,7 +591,7 @@ if __name__ == '__main__':
     #unique_puzzles=filter(lambda x: sudoku.SudokuSolver(x[0].grid,verbose=False).has_unique_solution(),puzzles)
     sm = SudokuMaker()
     #st = SudokuTracker(sm)
-elif False:    
+elif False:
     usage="""Commands are:
     run: Run sudoku-maker
     len: \# of puzzles generated
